#ifndef DATAMANAGER_SEEN
#define DATAMANAGER_SEEN

#include "abstractElement.h"
#include "globalParameters.h"
#include "nomdElements.h"
#include "particleBeam.h"
#include "sectionToExecute.h"
#include "nomDeLogiciel.h"
#include "trivaluedBool.h"
#include "beam2Moments.h"
#include "parmelaParticle.h"

class PspaApplication;

class dataManager
{
    
public:
    
    dataManager(PspaApplication*);
    virtual ~dataManager();
    
    int getBeamLineSize();
    inline globalParameters* getGlobalParameters()  {return &globParam_;}
    inline particleBeam* getCurrentBeam() {return currentBeam_;}
    
    particleBeam* getDiagnosticBeam(unsigned index);
    
    void addSectionToExecute(int debut, int fin, nomDeLogiciel prog);
    
    abstractElement* addElement(typedElement elemType);
    void removeElement(string);

    /**
     Get the label from the order number in the beam line
     @return return "" if not found
     */
    string getLabelFromElementNumero(int numero);

    /**
     Get the numero from the label in the beam line
     @return return -1 if not found
     */
    int getNumeroFromElementLabel(string);
    abstractElement* getElementPointerFromIndex(int);
    
    void initializeExecution();
    trivaluedBool checkExecute(string& diagnostic);
    trivaluedBool checkElementsForExec(nomDeLogiciel logiciel, unsigned indexDeb, unsigned indexFin, string& diagnostic);
    bool executeAll(string& resul);
    void saveConfiguration(string nameOfFile);
    bool restoreElements(string inputFileName);
    void donneesRmsEnveloppe( string type, unsigned int numeroDeb, unsigned int numeroFin, vector<double>& xcor, vector<double>& ycor);
    inline void setWorkingDir(string wd) {
        workingDir_ = wd;
    }
    
private:
    globalParameters globParam_;
    particleBeam* currentBeam_;
    
    vector<particleBeam> diagnosticBeam_;
    
    vector<sectionToExecute*> jobList_;
    
    void removeFile(string nameOfFile);
    void clearSectionToExecute();

    string workingDir_;
    PspaApplication* pspa_;
};
#endif
